@@ -44,7 +44,7 @@ class Class:
                     if code[0] == '{':
                         code = code[1:]
                     property_match = re.search(
-                        r'(public|internal|private|protected)\s*([a-zA-Z]*)\s*([a-zA-Z_<>]*)\s([a-zA-Z_0-9]*)\s*[\s\S]*?return ([\s\S]*?);', code)
+                        r'(public|internal|private|protected)\s*([a-zA-Z]*)\s*([a-zA-Z_<>]*)\s([a-zA-Z_0-9]*)\s*\s*{([\s\S]*)}', code)
 
                     if property_match is not None:
                         self.Propeties.append(
@@ -52,12 +52,12 @@ class Class:
                                      Is_static=property_match.group(2) == 'static',
                                      Return_type=property_match.group(3),
                                      Name=property_match.group(4),
-                                     Return_value=property_match.group(5),
+                                     Return_values=re.findall(r'return\s*([\s\S]*?;)', code),
                                      Code=code
                                      ))
 
                     method_match = re.search(
-                        r'(public|internal|private|protected)\s*(async|)\s*([a-zA-Z]*)\s*([a-zA-Z_]*)\(([a-zA-Z.0-9 ,]*)\)([\s\S]*?return\s*([\s\S]*?);|)', code)
+                        r'(public|internal|private|protected)\s*(async|)\s*([a-zA-Z]*)\s*([a-zA-Z_0-9]*)\(([a-zA-Z.0-9 ,]*)\)([\s\S]*?return\s*([\s\S]*?);|)', code)
 
                     if method_match is not None:
                         self.Methods.append(
